package com.qmth.distributed.print.business.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.UpdateWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.qmth.distributed.print.business.bean.marking.ClassMarker;
import com.qmth.distributed.print.business.entity.ExamPaperClassMarker;
import com.qmth.distributed.print.business.entity.ExamPaperStructure;
import com.qmth.distributed.print.business.enums.ExamPaperStructureStatusTypeEnum;
import com.qmth.distributed.print.business.mapper.ExamPaperClassMarkerMapper;
import com.qmth.distributed.print.business.service.ExamPaperClassMarkerService;
import com.qmth.distributed.print.business.service.ExamPaperStructureService;
import com.qmth.teachcloud.common.contant.SystemConstant;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.util.CollectionUtils;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.List;

/**
 * @Description: 班级和评卷员关系服务实现类
 */
@Service
public class ExamPaperClassMarkerServiceImpl extends ServiceImpl<ExamPaperClassMarkerMapper, ExamPaperClassMarker> implements ExamPaperClassMarkerService {

    @Resource
    ExamPaperStructureService examPaperStructureService;

    @Transactional
    @Override
    public void saveExamPaperClassInfo(ExamPaperStructure examPaperStructure, Boolean openClassReading, List<ClassMarker> classInfo) {
        // 1.删除原有数据
        this.deleteExamPaperClassInfo(examPaperStructure.getId());
        if (openClassReading && !CollectionUtils.isEmpty(classInfo)) {
            List<ExamPaperClassMarker> list = new ArrayList<>();
            for (ClassMarker classMarker : classInfo) {
                ExamPaperClassMarker examPaperClassMarker = new ExamPaperClassMarker();
                examPaperClassMarker.setId(SystemConstant.getDbUuid());
                examPaperClassMarker.setExamPaperStructureId(examPaperStructure.getId());
                examPaperClassMarker.setMarkerId(Long.valueOf(classMarker.getId()));
                examPaperClassMarker.setLoginName(classMarker.getLoginName());
                examPaperClassMarker.setClassName(classMarker.getClassName());
                list.add(examPaperClassMarker);
            }
            this.saveBatch(list);
            examPaperStructure.setStatus(ExamPaperStructure.parseStatus(examPaperStructure.getStatus(), ExamPaperStructureStatusTypeEnum.CLASS.getType(), "save", true));
            examPaperStructureService.updateById(examPaperStructure);
        }
    }

    @Override
    public void deleteExamPaperClassInfo(Long paperStructureId) {
        UpdateWrapper<ExamPaperClassMarker> updateWrapper = new UpdateWrapper<>();
        updateWrapper.lambda().eq(ExamPaperClassMarker::getExamPaperStructureId, paperStructureId);
        this.remove(updateWrapper);
    }

    @Override
    public List<ExamPaperClassMarker> listByExamPaperStructureId(Long id) {
        QueryWrapper<ExamPaperClassMarker> queryWrapper = new QueryWrapper<>();
        queryWrapper.lambda().eq(ExamPaperClassMarker::getExamPaperStructureId, id);
        return this.list(queryWrapper);
    }
}
